# Credits

## Development Lead

-   Core of Science \<<dev@coreofscience.com>\>

## Contributors

-   Oscar Arbeláez \<<odarbelaeze@gmail.com>\>
-   Juan David Alzate Cardona \<<jdalzatec@gmail.com>\>
-   Daniel Valencia \<<dsvalenciah@unal.edu.co>\>
